from setuptools import setup

setup(name="quanter",
      version="0.2",
      description="add function",
      url="",
      author="hugo",
      author_email="",
      license="MIT",
      packages=["quanter"],
      zip_safe=False)